package search;

import java.util.Map;

/**
 * Defines the external search interface
 * @author Stephen Tavener
 */
public interface ExternalSearchV1 {
	/**
	 * @param listener - provides asynchronous communication with GUI for feedback messages and early termination; 
	 * may be null if the search is called in a non-gui context, e.g. the analysis tools
	 * @param parameters - search parameters, e.g. time in seconds for search
	 * @param game - current game state, to be searched
	 * @return array of scores for each move from the game state; values should be between -1 (loss) and +1 (win)
	 */
	double[] search (final WorkerListener listener, final Map<String,Object> parameters, final Searchable game);
	
	/**
	 * Examples: thinking time, any debugging or behaviour flags
	 * @return a map containing string-value pairs describing any parameters required with default values
	 */
	Map<String,Object> parameters();	
	
	/**
	 * @return a concise string describing this search (used in the GUI)
	 */
	@Override
	public String toString();
}
