package search;

/**
 * Mechanism for reporting on search progress
 * @author Stephen Tavener
 *
 */
public interface WorkerListener {
	
	/**
	 * Called at the start of the task, sets the end point (could be a time or number of its) for progress reporting
	 * @param endPoint
	 */
	void startWork (final int endPoint);
	
	/**
	 * Report the current progress (number of its/time)
	 * @param stage
	 */
	void reportProgress (final int stage);
	
	/**
	 * Sends a feelgood message for display during progress
	 * @param feelGoodMessage
	 */
	void reportProgress (final String feelGoodMessage);

	/**
	 * Sends a feelgood message for display during progress
	 * @param feelGoodMessage
	 * @param path 
	 * @param count 
	 */
	void reportProgress (final String feelGoodMessage, int[] path, int count);
	
	/**
	 * Sends a feelgood message for display during progress
	 * @param feelGoodMessage
	 */
	void endWork (final String feelGoodMessage);

	/**
	 * Checks if the user has interrupted the worker thread
	 * @return true if early termination has been requested
	 */
	boolean isStopRequested();
	
	/**
	 * Interrupts the search in an AI-friendly way
	 */
	void stop();
}
